package javax.swing;

import java.awt.Dimension;
import javax.swing.plaf.DesktopIconUI;
import javax.accessibility.AccessibleRole;
import javax.accessibility.AccessibleValue;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.accessibility.AccessibleContext;
import java.awt.Graphics;
import java.io.IOException;
import java.io.ObjectOutputStream;
import javax.swing.event.InternalFrameEvent;
import javax.swing.event.InternalFrameListener;
import sun.swing.SwingUtilities2;
import java.awt.FocusTraversalPolicy;
import java.beans.PropertyVetoException;
import java.awt.Container;
import java.awt.LayoutManager;
import javax.swing.plaf.InternalFrameUI;
import sun.awt.SunToolkit;
import java.awt.BorderLayout;
import java.awt.Window;
import java.awt.KeyboardFocusManager;
import sun.awt.AppContext;
import java.awt.Component;
import java.awt.Rectangle;
import java.awt.Cursor;
import javax.accessibility.Accessible;

public class JInternalFrame extends JComponent implements Accessible, WindowConstants, RootPaneContainer
{
    private static final String uiClassID = "InternalFrameUI";
    protected JRootPane rootPane;
    protected boolean rootPaneCheckingEnabled;
    protected boolean closable;
    protected boolean isClosed;
    protected boolean maximizable;
    protected boolean isMaximum;
    protected boolean iconable;
    protected boolean isIcon;
    protected boolean resizable;
    protected boolean isSelected;
    protected Icon frameIcon;
    protected String title;
    protected JInternalFrame.JDesktopIcon desktopIcon;
    private Cursor lastCursor;
    private boolean opened;
    private Rectangle normalBounds;
    private int defaultCloseOperation;
    private Component lastFocusOwner;
    public static final String CONTENT_PANE_PROPERTY = "contentPane";
    public static final String MENU_BAR_PROPERTY = "JMenuBar";
    public static final String TITLE_PROPERTY = "title";
    public static final String LAYERED_PANE_PROPERTY = "layeredPane";
    public static final String ROOT_PANE_PROPERTY = "rootPane";
    public static final String GLASS_PANE_PROPERTY = "glassPane";
    public static final String FRAME_ICON_PROPERTY = "frameIcon";
    public static final String IS_SELECTED_PROPERTY = "selected";
    public static final String IS_CLOSED_PROPERTY = "closed";
    public static final String IS_MAXIMUM_PROPERTY = "maximum";
    public static final String IS_ICON_PROPERTY = "icon";
    private static final Object PROPERTY_CHANGE_LISTENER_KEY;
    boolean isDragging;
    boolean danger;
    
    private static void addPropertyChangeListenerIfNecessary() {
        if (AppContext.getAppContext().get(JInternalFrame.PROPERTY_CHANGE_LISTENER_KEY) == null) {
            JInternalFrame.FocusPropertyChangeListener focusPropertyChangeListener = new JInternalFrame.FocusPropertyChangeListener();
            AppContext.getAppContext().put(JInternalFrame.PROPERTY_CHANGE_LISTENER_KEY, focusPropertyChangeListener);
            KeyboardFocusManager.getCurrentKeyboardFocusManager().addPropertyChangeListener(focusPropertyChangeListener);
        }
    }
    
    private static void updateLastFocusOwner(Component parent) {
        if (parent != null) {
            for (; parent != null && !(parent instanceof Window); parent = parent.getParent()) {
                if ((parent instanceof JInternalFrame)) {
                    ((JInternalFrame)parent).setLastFocusOwner(parent);
                }
            }
        }
    }
    
    public JInternalFrame() {
        this("", false, false, false, false);
    }
    
    public JInternalFrame(String s) {
        this(s, false, false, false, false);
    }
    
    public JInternalFrame(String s, boolean b) {
        this(s, b, false, false, false);
    }
    
    public JInternalFrame(String s, boolean b, boolean b2) {
        this(s, b, b2, false, false);
    }
    
    public JInternalFrame(String s, boolean b, boolean b2, boolean b3) {
        this(s, b, b2, b3, false);
    }
    
    public JInternalFrame(String title, boolean resizable, boolean closable, boolean maximizable, boolean iconable) {
        this.rootPaneCheckingEnabled = false;
        this.normalBounds = null;
        this.defaultCloseOperation = 2;
        this.isDragging = false;
        this.danger = false;
        this.setRootPane(this.createRootPane());
        this.setLayout(new BorderLayout());
        this.title = title;
        this.resizable = resizable;
        this.closable = closable;
        this.maximizable = maximizable;
        this.isMaximum = false;
        this.iconable = iconable;
        this.setVisible(this.isIcon = false);
        this.setRootPaneCheckingEnabled(true);
        this.desktopIcon = new JInternalFrame.JDesktopIcon(this);
        this.updateUI();
        SunToolkit.checkAndSetPolicy(this);
        addPropertyChangeListenerIfNecessary();
    }
    
    protected JRootPane createRootPane() {
        return new JRootPane();
    }
    
    public InternalFrameUI getUI() {
        return (InternalFrameUI)this.ui;
    }
    
    public void setUI(InternalFrameUI ui) {
        int rootPaneCheckingEnabled = this.isRootPaneCheckingEnabled();
        try {
            this.setRootPaneCheckingEnabled(false);
            super.setUI(ui);
        }
        finally {
            this.setRootPaneCheckingEnabled((boolean)rootPaneCheckingEnabled);
        }
    }
    
    @Override
    public void updateUI() {
        this.setUI((InternalFrameUI)UIManager.getUI(this));
        this.invalidate();
        if (this.desktopIcon != null) {
            this.desktopIcon.updateUIWhenHidden();
        }
    }
    
    void updateUIWhenHidden() {
        this.setUI((InternalFrameUI)UIManager.getUI(this));
        this.invalidate();
        Component[] components = this.getComponents();
        if (components != null) {
            for (int length = components.length, i = 0; i < length; ++i) {
                SwingUtilities.updateComponentTreeUI(components[i]);
            }
        }
    }
    
    @Override
    public String getUIClassID() {
        return "InternalFrameUI";
    }
    
    protected boolean isRootPaneCheckingEnabled() {
        return this.rootPaneCheckingEnabled;
    }
    
    protected void setRootPaneCheckingEnabled(boolean rootPaneCheckingEnabled) {
        this.rootPaneCheckingEnabled = rootPaneCheckingEnabled;
    }
    
    @Override
    protected void addImpl(Component component, Object o, int n) {
        if (this.isRootPaneCheckingEnabled()) {
            this.getContentPane().add(component, o, n);
        }
        else {
            super.addImpl(component, o, n);
        }
    }
    
    @Override
    public void remove(Component component) {
        int componentCount = this.getComponentCount();
        super.remove(component);
        if (componentCount == this.getComponentCount()) {
            this.getContentPane().remove(component);
        }
    }
    
    @Override
    public void setLayout(LayoutManager layoutManager) {
        if (this.isRootPaneCheckingEnabled()) {
            this.getContentPane().setLayout(layoutManager);
        }
        else {
            super.setLayout(layoutManager);
        }
    }
    
    @Deprecated
    public JMenuBar getMenuBar() {
        return this.getRootPane().getMenuBar();
    }
    
    public JMenuBar getJMenuBar() {
        return this.getRootPane().getJMenuBar();
    }
    
    @Deprecated
    public void setMenuBar(JMenuBar menuBar) {
        JMenuBar menuBar2 = this.getMenuBar();
        this.getRootPane().setJMenuBar(menuBar);
        this.firePropertyChange("JMenuBar", menuBar2, menuBar);
    }
    
    public void setJMenuBar(JMenuBar menuBar) {
        JMenuBar menuBar2 = this.getMenuBar();
        this.getRootPane().setJMenuBar(menuBar);
        this.firePropertyChange("JMenuBar", menuBar2, menuBar);
    }
    
    @Override
    public Container getContentPane() {
        return this.getRootPane().getContentPane();
    }
    
    @Override
    public void setContentPane(Container container) {
        Container contentPane = this.getContentPane();
        this.getRootPane().setContentPane(container);
        this.firePropertyChange("contentPane", contentPane, container);
    }
    
    @Override
    public JLayeredPane getLayeredPane() {
        return this.getRootPane().getLayeredPane();
    }
    
    @Override
    public void setLayeredPane(JLayeredPane layeredPane) {
        JLayeredPane layeredPane2 = this.getLayeredPane();
        this.getRootPane().setLayeredPane(layeredPane);
        this.firePropertyChange("layeredPane", layeredPane2, layeredPane);
    }
    
    @Override
    public Component getGlassPane() {
        return this.getRootPane().getGlassPane();
    }
    
    @Override
    public void setGlassPane(Component component) {
        Component glassPane = this.getGlassPane();
        this.getRootPane().setGlassPane(component);
        this.firePropertyChange("glassPane", glassPane, component);
    }
    
    @Override
    public JRootPane getRootPane() {
        return this.rootPane;
    }
    
    protected void setRootPane(JRootPane rootPane) {
        if (this.rootPane != null) {
            this.remove(this.rootPane);
        }
        JRootPane rootPane2 = this.getRootPane();
        this.rootPane = rootPane;
        if (this.rootPane != null) {
            int rootPaneCheckingEnabled = this.isRootPaneCheckingEnabled();
            try {
                this.setRootPaneCheckingEnabled(false);
                this.add(this.rootPane, "Center");
            }
            finally {
                this.setRootPaneCheckingEnabled((boolean)rootPaneCheckingEnabled);
            }
        }
        this.firePropertyChange("rootPane", rootPane2, rootPane);
    }
    
    public void setClosable(boolean closable) {
        Boolean oldValue = this.closable ? Boolean.TRUE : Boolean.FALSE;
        Boolean newValue = closable ? Boolean.TRUE : Boolean.FALSE;
        this.closable = closable;
        this.firePropertyChange("closable", oldValue, newValue);
    }
    
    public boolean isClosable() {
        return this.closable;
    }
    
    public boolean isClosed() {
        return this.isClosed;
    }
    
    public void setClosed(boolean isClosed) throws PropertyVetoException {
        if (this.isClosed == isClosed) {
            return;
        }
        Boolean oldValue = this.isClosed ? Boolean.TRUE : Boolean.FALSE;
        Boolean newValue = isClosed ? Boolean.TRUE : Boolean.FALSE;
        if (isClosed) {
            this.fireInternalFrameEvent(25550);
        }
        this.fireVetoableChange("closed", oldValue, newValue);
        this.isClosed = isClosed;
        if (this.isClosed) {
            this.setVisible(false);
        }
        this.firePropertyChange("closed", oldValue, newValue);
        if (this.isClosed) {
            this.dispose();
        }
        else {
            boolean opened = this.opened;
        }
        return;
    }
    
    public void setResizable(boolean resizable) {
        Boolean oldValue = this.resizable ? Boolean.TRUE : Boolean.FALSE;
        Boolean newValue = resizable ? Boolean.TRUE : Boolean.FALSE;
        this.resizable = resizable;
        this.firePropertyChange("resizable", oldValue, newValue);
    }
    
    public boolean isResizable() {
        return !this.isMaximum && this.resizable;
    }
    
    public void setIconifiable(boolean iconable) {
        Boolean oldValue = this.iconable ? Boolean.TRUE : Boolean.FALSE;
        Boolean newValue = iconable ? Boolean.TRUE : Boolean.FALSE;
        this.iconable = iconable;
        this.firePropertyChange("iconable", oldValue, newValue);
    }
    
    public boolean isIconifiable() {
        return this.iconable;
    }
    
    public boolean isIcon() {
        return this.isIcon;
    }
    
    public void setIcon(boolean isIcon) throws PropertyVetoException {
        if (this.isIcon == isIcon) {
            return;
        }
        this.firePropertyChange("ancestor", null, this.getParent());
        Boolean oldValue = this.isIcon ? Boolean.TRUE : Boolean.FALSE;
        Boolean newValue = isIcon ? Boolean.TRUE : Boolean.FALSE;
        this.fireVetoableChange("icon", oldValue, newValue);
        this.isIcon = isIcon;
        this.firePropertyChange("icon", oldValue, newValue);
        if (isIcon) {
            this.fireInternalFrameEvent(25552);
        }
        else {
            this.fireInternalFrameEvent(25553);
        }
        return;
    }
    
    public void setMaximizable(boolean maximizable) {
        Boolean oldValue = this.maximizable ? Boolean.TRUE : Boolean.FALSE;
        Boolean newValue = maximizable ? Boolean.TRUE : Boolean.FALSE;
        this.maximizable = maximizable;
        this.firePropertyChange("maximizable", oldValue, newValue);
    }
    
    public boolean isMaximizable() {
        return this.maximizable;
    }
    
    public boolean isMaximum() {
        return this.isMaximum;
    }
    
    public void setMaximum(boolean isMaximum) throws PropertyVetoException {
        if (this.isMaximum == isMaximum) {
            return;
        }
        Boolean oldValue = this.isMaximum ? Boolean.TRUE : Boolean.FALSE;
        Boolean newValue = isMaximum ? Boolean.TRUE : Boolean.FALSE;
        this.fireVetoableChange("maximum", oldValue, newValue);
        this.isMaximum = isMaximum;
        this.firePropertyChange("maximum", oldValue, newValue);
        return;
    }
    
    public String getTitle() {
        return this.title;
    }
    
    public void setTitle(String title) {
        this.firePropertyChange("title", this.title, this.title = title);
    }
    
    public void setSelected(boolean isSelected) throws PropertyVetoException {
        if (isSelected && this.isSelected) {
            this.restoreSubcomponentFocus();
            return;
        }
        if (this.isSelected == isSelected || (isSelected && !(this.isIcon ? this.desktopIcon.isShowing() : this.isShowing()))) {
            return;
        }
        Boolean oldValue = this.isSelected ? Boolean.TRUE : Boolean.FALSE;
        Boolean newValue = isSelected ? Boolean.TRUE : Boolean.FALSE;
        this.fireVetoableChange("selected", oldValue, newValue);
        if (isSelected) {
            this.restoreSubcomponentFocus();
        }
        this.isSelected = isSelected;
        this.firePropertyChange("selected", oldValue, newValue);
        if (this.isSelected) {
            this.fireInternalFrameEvent(25554);
        }
        else {
            this.fireInternalFrameEvent(25555);
        }
        this.repaint();
        return;
    }
    
    public boolean isSelected() {
        return this.isSelected;
    }
    
    public void setFrameIcon(Icon frameIcon) {
        this.firePropertyChange("frameIcon", this.frameIcon, this.frameIcon = frameIcon);
    }
    
    public Icon getFrameIcon() {
        return this.frameIcon;
    }
    
    public void moveToFront() {
        if (this.isIcon()) {
            if ((this.getDesktopIcon().getParent() instanceof JLayeredPane)) {
                ((JLayeredPane)this.getDesktopIcon().getParent()).moveToFront(this.getDesktopIcon());
            }
        }
        else if ((this.getParent() instanceof JLayeredPane)) {
            ((JLayeredPane)this.getParent()).moveToFront(this);
        }
    }
    
    public void moveToBack() {
        if (this.isIcon()) {
            if ((this.getDesktopIcon().getParent() instanceof JLayeredPane)) {
                ((JLayeredPane)this.getDesktopIcon().getParent()).moveToBack(this.getDesktopIcon());
            }
        }
        else if ((this.getParent() instanceof JLayeredPane)) {
            ((JLayeredPane)this.getParent()).moveToBack(this);
        }
    }
    
    public Cursor getLastCursor() {
        return this.lastCursor;
    }
    
    @Override
    public void setCursor(Cursor cursor) {
        if (cursor == null) {
            this.lastCursor = null;
            super.setCursor(cursor);
            return;
        }
        int type = cursor.getType();
        if (type != 4 && type != 5 && type != 6 && type != 7 && type != 8 && type != 9 && type != 10 && type != 11) {
            this.lastCursor = cursor;
        }
        super.setCursor(cursor);
        return;
    }
    
    public void setLayer(Integer n) {
        if (this.getParent() != null && this.getParent() instanceof JLayeredPane) {
            JLayeredPane layeredPane = (JLayeredPane)this.getParent();
            layeredPane.setLayer(this, (int)n, layeredPane.getPosition(this));
        }
        else {
            JLayeredPane.putLayer(this, (int)n);
            if (this.getParent() != null) {
                this.getParent().repaint(this.getX(), this.getY(), this.getWidth(), this.getHeight());
            }
        }
    }
    
    public void setLayer(int i) {
        this.setLayer(Integer.valueOf(i));
    }
    
    public int getLayer() {
        return JLayeredPane.getLayer(this);
    }
    
    public JDesktopPane getDesktopPane() {
        Container container;
        for (container = this.getParent(); container != null && !(container instanceof JDesktopPane); container = container.getParent()) {}
        if (container == null) {
            for (container = this.getDesktopIcon().getParent(); container != null && !(container instanceof JDesktopPane); container = container.getParent()) {}
        }
        return (JDesktopPane)container;
    }
    
    public void setDesktopIcon(JInternalFrame.JDesktopIcon desktopIcon) {
        this.firePropertyChange("desktopIcon", this.getDesktopIcon(), this.desktopIcon = desktopIcon);
    }
    
    public JInternalFrame.JDesktopIcon getDesktopIcon() {
        return this.desktopIcon;
    }
    
    public Rectangle getNormalBounds() {
        if (this.normalBounds != null) {
            return this.normalBounds;
        }
        return this.getBounds();
    }
    
    public void setNormalBounds(Rectangle normalBounds) {
        this.normalBounds = normalBounds;
    }
    
    public Component getFocusOwner() {
        if (this.isSelected()) {
            return this.lastFocusOwner;
        }
        return null;
    }
    
    public Component getMostRecentFocusOwner() {
        if (this.isSelected()) {
            return this.getFocusOwner();
        }
        if (this.lastFocusOwner != null) {
            return this.lastFocusOwner;
        }
        FocusTraversalPolicy focusTraversalPolicy = this.getFocusTraversalPolicy();
        if ((focusTraversalPolicy instanceof InternalFrameFocusTraversalPolicy)) {
            return ((InternalFrameFocusTraversalPolicy)focusTraversalPolicy).getInitialComponent(this);
        }
        Component defaultComponent = focusTraversalPolicy.getDefaultComponent(this);
        if (defaultComponent != null) {
            return defaultComponent;
        }
        return this.getContentPane();
    }
    
    public void restoreSubcomponentFocus() {
        if (this.isIcon()) {
            SwingUtilities2.compositeRequestFocus(this.getDesktopIcon());
        }
        else {
            Component permanentFocusOwner = KeyboardFocusManager.getCurrentKeyboardFocusManager().getPermanentFocusOwner();
            if (permanentFocusOwner == null || !SwingUtilities.isDescendingFrom(permanentFocusOwner, this)) {
                this.setLastFocusOwner(this.getMostRecentFocusOwner());
                if (this.lastFocusOwner == null) {
                    this.setLastFocusOwner(this.getContentPane());
                }
                this.lastFocusOwner.requestFocus();
            }
        }
    }
    
    private void setLastFocusOwner(Component lastFocusOwner) {
        this.lastFocusOwner = lastFocusOwner;
    }
    
    @Override
    public void reshape(int n, int n2, int n3, int n4) {
        super.reshape(n, n2, n3, n4);
        this.validate();
        this.repaint();
    }
    
    public void addInternalFrameListener(InternalFrameListener l) {
        this.listenerList.add(InternalFrameListener.class, l);
        this.enableEvents(0L);
    }
    
    public void removeInternalFrameListener(InternalFrameListener l) {
        this.listenerList.remove(InternalFrameListener.class, l);
    }
    
    public InternalFrameListener[] getInternalFrameListeners() {
        return (InternalFrameListener[])this.listenerList.getListeners(InternalFrameListener.class);
    }
    
    protected void fireInternalFrameEvent(int id) {
        Object[] listenerList = this.listenerList.getListenerList();
        Object o = null;
        for (int i = listenerList.length - 2; i >= 0; i -= 2) {
            if (listenerList[i] == InternalFrameListener.class) {
                if (o == null) {
                    o = new InternalFrameEvent(this, id);
                }
                switch (o.getID()) {
                    case 25549: {
                        ((InternalFrameListener)listenerList[i + 1]).internalFrameOpened(o);
                        break;
                    }
                    case 25550: {
                        ((InternalFrameListener)listenerList[i + 1]).internalFrameClosing(o);
                        break;
                    }
                    case 25551: {
                        ((InternalFrameListener)listenerList[i + 1]).internalFrameClosed(o);
                        break;
                    }
                    case 25552: {
                        ((InternalFrameListener)listenerList[i + 1]).internalFrameIconified(o);
                        break;
                    }
                    case 25553: {
                        ((InternalFrameListener)listenerList[i + 1]).internalFrameDeiconified(o);
                        break;
                    }
                    case 25554: {
                        ((InternalFrameListener)listenerList[i + 1]).internalFrameActivated(o);
                        break;
                    }
                    case 25555: {
                        ((InternalFrameListener)listenerList[i + 1]).internalFrameDeactivated(o);
                        break;
                    }
                }
            }
        }
    }
    
    public void doDefaultCloseAction() {
        this.fireInternalFrameEvent(25550);
        switch (this.defaultCloseOperation) {
            case 0: {
                break;
            }
            case 1: {
                this.setVisible(false);
                if (this.isSelected()) {
                    try {
                        this.setSelected(false);
                        break;
                    }
                    catch (PropertyVetoException ex) {
                        break;
                    }
                    break;
                }
                break;
            }
            case 2: {
                try {
                    this.fireVetoableChange("closed", Boolean.FALSE, Boolean.TRUE);
                    this.isClosed = true;
                    this.setVisible(false);
                    this.firePropertyChange("closed", Boolean.FALSE, Boolean.TRUE);
                    this.dispose();
                    break;
                }
                catch (PropertyVetoException ex2) {
                    break;
                }
            }
        }
    }
    
    public void setDefaultCloseOperation(int defaultCloseOperation) {
        this.defaultCloseOperation = defaultCloseOperation;
    }
    
    public int getDefaultCloseOperation() {
        return this.defaultCloseOperation;
    }
    
    public void pack() {
        try {
            if (this.isIcon()) {
                this.setIcon(false);
            }
            else if (this.isMaximum()) {
                this.setMaximum(false);
            }
        }
        catch (PropertyVetoException ex) {
            return;
        }
        this.setSize(this.getPreferredSize());
        this.validate();
    }
    
    @Override
    public void show() {
        if (this.isVisible()) {
            return;
        }
        if (!this.opened) {
            this.fireInternalFrameEvent(25549);
            this.opened = true;
        }
        this.getDesktopIcon().setVisible(true);
        this.toFront();
        super.show();
        if (this.isIcon) {
            return;
        }
        if (!this.isSelected()) {
            try {
                this.setSelected(true);
            }
            catch (PropertyVetoException ex) {}
        }
        return;
    }
    
    @Override
    public void hide() {
        if (this.isIcon()) {
            this.getDesktopIcon().setVisible(false);
        }
        super.hide();
    }
    
    public void dispose() {
        if (this.isVisible()) {
            this.setVisible(false);
        }
        if (this.isSelected()) {
            try {
                this.setSelected(false);
            }
            catch (PropertyVetoException ex) {}
        }
        if (!this.isClosed) {
            this.firePropertyChange("closed", Boolean.FALSE, Boolean.TRUE);
            this.isClosed = true;
        }
        this.fireInternalFrameEvent(25551);
    }
    
    public void toFront() {
        this.moveToFront();
    }
    
    public void toBack() {
        this.moveToBack();
    }
    
    @Override
    public final void setFocusCycleRoot(boolean b) {
    }
    
    @Override
    public final boolean isFocusCycleRoot() {
        return true;
    }
    
    @Override
    public final Container getFocusCycleRootAncestor() {
        return null;
    }
    
    public final String getWarningString() {
        return null;
    }
    
    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        objectOutputStream.defaultWriteObject();
        if (this.getUIClassID().equals("InternalFrameUI")) {
            int n = (byte)(JComponent.getWriteObjCounter(this) - 1);
            JComponent.setWriteObjCounter(this, (byte)n);
            if (n == 0 && this.ui != null) {
                int rootPaneCheckingEnabled = this.isRootPaneCheckingEnabled();
                try {
                    this.setRootPaneCheckingEnabled(false);
                    this.ui.installUI(this);
                }
                finally {
                    this.setRootPaneCheckingEnabled((boolean)rootPaneCheckingEnabled);
                }
            }
        }
    }
    
    @Override
    void compWriteObjectNotify() {
        int rootPaneCheckingEnabled = this.isRootPaneCheckingEnabled();
        try {
            this.setRootPaneCheckingEnabled(false);
            super.compWriteObjectNotify();
        }
        finally {
            this.setRootPaneCheckingEnabled((boolean)rootPaneCheckingEnabled);
        }
    }
    
    @Override
    protected String paramString() {
        String str = (this.rootPane != null) ? this.rootPane.toString() : "";
        String str2 = this.rootPaneCheckingEnabled ? "true" : "false";
        String str3 = this.closable ? "true" : "false";
        String str4 = this.isClosed ? "true" : "false";
        String str5 = this.maximizable ? "true" : "false";
        String str6 = this.isMaximum ? "true" : "false";
        String str7 = this.iconable ? "true" : "false";
        String str8 = this.isIcon ? "true" : "false";
        String str9 = this.resizable ? "true" : "false";
        String str10 = this.isSelected ? "true" : "false";
        String str11 = (this.frameIcon != null) ? this.frameIcon.toString() : "";
        String str12 = (this.title != null) ? this.title : "";
        String str13 = (this.desktopIcon != null) ? this.desktopIcon.toString() : "";
        String str14 = this.opened ? "true" : "false";
        String str15;
        if (this.defaultCloseOperation == 1) {
            str15 = "HIDE_ON_CLOSE";
        }
        else if (this.defaultCloseOperation == 2) {
            str15 = "DISPOSE_ON_CLOSE";
        }
        else if (this.defaultCloseOperation == 0) {
            str15 = "DO_NOTHING_ON_CLOSE";
        }
        else {
            str15 = "";
        }
        return super.paramString() + ",closable=" + str3 + ",defaultCloseOperation=" + str15 + ",desktopIcon=" + str13 + ",frameIcon=" + str11 + ",iconable=" + str7 + ",isClosed=" + str4 + ",isIcon=" + str8 + ",isMaximum=" + str6 + ",isSelected=" + str10 + ",maximizable=" + str5 + ",opened=" + str14 + ",resizable=" + str9 + ",rootPane=" + str + ",rootPaneCheckingEnabled=" + str2 + ",title=" + str12;
    }
    
    @Override
    protected void paintComponent(Graphics graphics) {
        if (this.isDragging) {
            this.danger = true;
        }
        super.paintComponent(graphics);
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new JInternalFrame.AccessibleJInternalFrame();
        }
        return this.accessibleContext;
    }
    
    static void access$100(Component component) {
        updateLastFocusOwner(component);
    }
    
    static {
        PROPERTY_CHANGE_LISTENER_KEY = new StringBuilder("InternalFramePropertyChangeListener");
    }
    
    private static class FocusPropertyChangeListener implements PropertyChangeListener
    {
        @Override
        public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
            if (propertyChangeEvent.getPropertyName() == "permanentFocusOwner") {
                JInternalFrame.access$100((Component)propertyChangeEvent.getNewValue());
            }
        }
    }
    
    protected class AccessibleJInternalFrame extends JComponent.AccessibleJComponent implements AccessibleValue
    {
        @Override
        public String getAccessibleName() {
            String s = this.accessibleName;
            if (s == null) {
                s = (String)JInternalFrame.this.getClientProperty("AccessibleName");
            }
            if (s == null) {
                s = JInternalFrame.this.getTitle();
                return s;
            }
            return s;
        }
        
        @Override
        public AccessibleRole getAccessibleRole() {
            return AccessibleRole.INTERNAL_FRAME;
        }
        
        @Override
        public AccessibleValue getAccessibleValue() {
            return this;
        }
        
        @Override
        public Number getCurrentAccessibleValue() {
            return Integer.valueOf(JInternalFrame.this.getLayer());
        }
        
        @Override
        public boolean setCurrentAccessibleValue(Number n) {
            if (n == null) {
                return false;
            }
            JInternalFrame.this.setLayer(new Integer(n.intValue()));
            return true;
        }
        
        @Override
        public Number getMinimumAccessibleValue() {
            return Integer.valueOf(Integer.MIN_VALUE);
        }
        
        @Override
        public Number getMaximumAccessibleValue() {
            return Integer.valueOf(Integer.MAX_VALUE);
        }
    }
    
    public static class JDesktopIcon extends JComponent implements Accessible
    {
        JInternalFrame internalFrame;
        
        public JDesktopIcon(JInternalFrame internalFrame) {
            this.setVisible(false);
            this.setInternalFrame(internalFrame);
            this.updateUI();
        }
        
        public DesktopIconUI getUI() {
            return (DesktopIconUI)this.ui;
        }
        
        public void setUI(DesktopIconUI ui) {
            super.setUI(ui);
        }
        
        public JInternalFrame getInternalFrame() {
            return this.internalFrame;
        }
        
        public void setInternalFrame(JInternalFrame internalFrame) {
            this.internalFrame = internalFrame;
        }
        
        public JDesktopPane getDesktopPane() {
            if (this.getInternalFrame() != null) {
                return this.getInternalFrame().getDesktopPane();
            }
            return null;
        }
        
        @Override
        public void updateUI() {
            int n = this.ui != null;
            this.setUI((DesktopIconUI)UIManager.getUI(this));
            this.invalidate();
            Dimension preferredSize = this.getPreferredSize();
            this.setSize(preferredSize.width, preferredSize.height);
            if (this.internalFrame != null && this.internalFrame.getUI() != null) {
                SwingUtilities.updateComponentTreeUI(this.internalFrame);
            }
        }
        
        void updateUIWhenHidden() {
            this.setUI((DesktopIconUI)UIManager.getUI(this));
            Dimension preferredSize = this.getPreferredSize();
            this.setSize(preferredSize.width, preferredSize.height);
            this.invalidate();
            Component[] components = this.getComponents();
            if (components != null) {
                for (int length = components.length, i = 0; i < length; ++i) {
                    SwingUtilities.updateComponentTreeUI(components[i]);
                }
            }
        }
        
        @Override
        public String getUIClassID() {
            return "DesktopIconUI";
        }
        
        private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
            objectOutputStream.defaultWriteObject();
            if (this.getUIClassID().equals("DesktopIconUI")) {
                int n = (byte)(JComponent.getWriteObjCounter(this) - 1);
                JComponent.setWriteObjCounter(this, (byte)n);
                if (n == 0 && this.ui != null) {
                    this.ui.installUI(this);
                }
            }
        }
        
        @Override
        public AccessibleContext getAccessibleContext() {
            if (this.accessibleContext == null) {
                this.accessibleContext = new JInternalFrame.JDesktopIcon.AccessibleJDesktopIcon();
            }
            return this.accessibleContext;
        }
        
        protected class AccessibleJDesktopIcon extends JComponent.AccessibleJComponent implements AccessibleValue
        {
            @Override
            public AccessibleRole getAccessibleRole() {
                return AccessibleRole.DESKTOP_ICON;
            }
            
            @Override
            public AccessibleValue getAccessibleValue() {
                return this;
            }
            
            @Override
            public Number getCurrentAccessibleValue() {
                AccessibleValue accessibleValue = JInternalFrame.JDesktopIcon.this.getInternalFrame().getAccessibleContext().getAccessibleValue();
                if (accessibleValue != null) {
                    return accessibleValue.getCurrentAccessibleValue();
                }
                return null;
            }
            
            @Override
            public boolean setCurrentAccessibleValue(Number currentAccessibleValue) {
                if (currentAccessibleValue == null) {
                    return false;
                }
                AccessibleValue accessibleValue = JInternalFrame.JDesktopIcon.this.getInternalFrame().getAccessibleContext().getAccessibleValue();
                return accessibleValue != null && accessibleValue.setCurrentAccessibleValue(currentAccessibleValue);
            }
            
            @Override
            public Number getMinimumAccessibleValue() {
                AccessibleContext accessibleContext = JInternalFrame.JDesktopIcon.this.getInternalFrame().getAccessibleContext();
                if ((accessibleContext instanceof AccessibleValue)) {
                    return ((AccessibleValue)accessibleContext).getMinimumAccessibleValue();
                }
                return null;
            }
            
            @Override
            public Number getMaximumAccessibleValue() {
                AccessibleContext accessibleContext = JInternalFrame.JDesktopIcon.this.getInternalFrame().getAccessibleContext();
                if ((accessibleContext instanceof AccessibleValue)) {
                    return ((AccessibleValue)accessibleContext).getMaximumAccessibleValue();
                }
                return null;
            }
        }
    }
}
